==> pipewire-docs-1%3A0.3.33-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__core.js <==
var group__pw__core =
[
    [ "pw_core_info", "structpw__core__info.html", [
      [ "change_mask", "structpw__core__info.html#a25d93390dbafcb433827ec29c195404f", null ],
      [ "cookie", "structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083", null ],
      [ "host_name", "structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f", null ],
      [ "id", "structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca", null ],
      [ "name", "structpw__core__info.html#ae0fb9270f0212f68c7343b03fb9dc401", null ],
      [ "props", "structpw__core__info.html#a11e9dea8aeb559ad12730b2741447d94", null ],
      [ "user_name", "structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42", null ],
      [ "version", "structpw__core__info.html#a3e394e50023a597dafb391887249d4eb", null ]
    ] ],
    [ "pw_core_events", "structpw__core__events.html", [
      [ "add_mem", "structpw__core__events.html#aeaf261e59f9a58b5005418abf669271a", null ],
      [ "bound_id", "structpw__core__events.html#ae99597f5f149475172942064d4911961", null ],
      [ "done", "structpw__core__events.html#a6cf547297486e97c8969a1e08d837955", null ],
      [ "error", "structpw__core__events.html#a55c28400675736b9365e711884f7a73b", null ],
      [ "info", "structpw__core__events.html#aa6aae56a5a9eb60fd5a308bec837b0e6", null ],
      [ "ping", "structpw__core__events.html#ada596905cb8c963eee644a638b6628c2", null ],
      [ "remove_id", "structpw__core__events.html#a9a930f32ad895727dffbeb6ae4c6e04d", null ],
      [ "remove_mem", "structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063", null ],
      [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ]
    ] ],
    [ "pw_core_methods", "structpw__core__methods.html", [
      [ "add_listener", "structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703", null ],
      [ "create_object", "structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459", null ],
      [ "destroy", "structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309", null ],
      [ "error", "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa", null ],
      [ "get_registry", "structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2", null ],
      [ "hello", "structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5", null ],
      [ "pong", "structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9", null ],
      [ "sync", "structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176", null ],
      [ "version", "structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a", null ]
    ] ],
    [ "pw_core_add_listener", "group__pw__core.html#gab938c1e0b4439c86f0c073d2359fefb0", null ],
    [ "pw_core_destroy", "group__pw__core.html#ga747c2d5f60d3171f81ac5d58c34042a3", null ],
    [ "pw_core_error", "group__pw__core.html#ga1c0700d8582be8c02db04c4f907b55c9", null ],
    [ "PW_CORE_EVENT_ADD_MEM", "group__pw__core.html#gaa324107a2eb26e55ec2a6fab7c12cbc4", null ],
    [ "PW_CORE_EVENT_BOUND_ID", "group__pw__core.html#ga7f5253f01173106d9f4204e6803f9eb7", null ],
    [ "PW_CORE_EVENT_DONE", "group__pw__core.html#ga6320395eb7b0608d72876f528356d804", null ],
    [ "PW_CORE_EVENT_ERROR", "group__pw__core.html#ga26ec3a93936820d7766d161bd2061dde", null ],
    [ "PW_CORE_EVENT_INFO", "group__pw__core.html#ga20d8f8b7de5d61fd26279335081a650f", null ],
    [ "PW_CORE_EVENT_NUM", "group__pw__core.html#gab5ff84f4e96706dcaf698a889d31ebb2", null ],
    [ "PW_CORE_EVENT_PING", "group__pw__core.html#gae5baf4bb04dc57c2f56c6ebe55495ee4", null ],
    [ "PW_CORE_EVENT_REMOVE_ID", "group__pw__core.html#ga32442cfb83722413b8769555194f1837", null ],
    [ "PW_CORE_EVENT_REMOVE_MEM", "group__pw__core.html#gaf42a0b2aece1dbb787791d92ccc9bf4c", null ],
    [ "pw_core_hello", "group__pw__core.html#gaeacb97f0a612cff9d5fdb16e2a205444", null ],
    [ "pw_core_method", "group__pw__core.html#gac59eea3db133de67f1b1c0ab4cab0047", null ],
    [ "PW_CORE_METHOD_ADD_LISTENER", "group__pw__core.html#gab198dbd1143e47953104e4aa52106562", null ],
    [ "PW_CORE_METHOD_CREATE_OBJECT", "group__pw__core.html#ga3c4c5529b9bb6c9188053bdf1604c2e0", null ],
    [ "PW_CORE_METHOD_DESTROY", "group__pw__core.html#ga22add02684ab6cf7bcbb5971abf11b43", null ],
    [ "PW_CORE_METHOD_ERROR", "group__pw__core.html#gaad9f6725ef7bf5a40abc3993ee0eb661", null ],
    [ "PW_CORE_METHOD_GET_REGISTRY", "group__pw__core.html#ga61a14cc040ef8af2843ab3269292bee9", null ],
    [ "PW_CORE_METHOD_HELLO", "group__pw__core.html#ga91db1c249a8b6373869a6dc1461728b7", null ],
    [ "PW_CORE_METHOD_NUM", "group__pw__core.html#ga3377b3f78973fe86c320832c7c78ca11", null ],
    [ "PW_CORE_METHOD_PONG", "group__pw__core.html#ga4cf14818a2b4d7d2841e43d14706f24e", null ],
    [ "PW_CORE_METHOD_SYNC", "group__pw__core.html#ga7af83aeb249cf504499536e95793f650", null ],
    [ "pw_core_pong", "group__pw__core.html#ga50323f15b69d13b86fe1d59d6dd3bfba", null ],
    [ "pw_core_sync", "group__pw__core.html#ga02b3e6ff573afd1efba25efc8bbb2538", null ],
    [ "PW_DEFAULT_REMOTE", "group__pw__core.html#ga7a2591e137e97b0a693c0788031acab7", null ],
    [ "PW_ID_ANY", "group__pw__core.html#ga5e904a63584ce9699c5c192bb4473cf9", null ],
    [ "PW_ID_CORE", "group__pw__core.html#ga4083f3e9e51198a675c7fb0aa0f91769", null ],
    [ "PW_TYPE_INTERFACE_Core", "group__pw__core.html#ga4828b5ffb309b2d8a985e0ee4fc80978", null ],
    [ "PW_TYPE_INTERFACE_Registry", "group__pw__core.html#gab77f9f893b6d0a0cc0827738479673e2", null ],
    [ "PW_VERSION_CORE", "group__pw__core.html#gaa1b9fbcde86380fd115be191535ccdf5", null ],
    [ "PW_VERSION_REGISTRY", "group__pw__core.html#gab44caf825808814cb78f9b6426457066", null ],
    [ "pw_context_connect", "group__pw__core.html#ga4b09778318ce5e2b052c97d0b682bcb8", null ],
    [ "pw_context_connect_fd", "group__pw__core.html#gab89bcb7e1787678a2b09fa5d14c5cc24", null ],
    [ "pw_context_connect_self", "group__pw__core.html#ga6054783cae25cc015e383d42859ed9fd", null ],
    [ "pw_core_disconnect", "group__pw__core.html#gaa0ad30957ad355b5217f161cc7847c2f", null ],
    [ "pw_core_export", "group__pw__core.html#gaeec5af2a95a2832be12040373692f418", null ],
    [ "pw_core_find_proxy", "group__pw__core.html#ga9bece479058aadc19eec3fa48c505c80", null ],
    [ "pw_core_get_client", "group__pw__core.html#ga7d4d4b6be256e573601ec9dd8a11fce8", null ],
    [ "pw_core_get_context", "group__pw__core.html#gabe419f6137cab191611fef10ed01a6ec", null ],
    [ "pw_core_get_mempool", "group__pw__core.html#ga83837cdc967956ccc670b515b0b7d3c8", null ],
    [ "pw_core_get_properties", "group__pw__core.html#gac1fcf434e5d5080943c15fc07fa29a99", null ],
    [ "pw_core_get_user_data", "group__pw__core.html#ga81e701a48df18c8992c262e6ecd5a741", null ],
    [ "pw_core_info_free", "group__pw__core.html#gacd6e564b199ca16be48656e77cb5003a", null ],
    [ "pw_core_info_update", "group__pw__core.html#ga83f9c89a2262abff85ca35a7a379d499", null ],
    [ "pw_core_set_paused", "group__pw__core.html#gacd4995c9a07c46f925b28bf4c653f2df", null ],
    [ "pw_core_steal_fd", "group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f", null ],
    [ "pw_core_update_properties", "group__pw__core.html#ga9918e38cb727fa7b8d59cca7b318f3c7", null ]
];

==> pipewire-docs-1%3A0.3.49-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__core.js <==
var group__pw__core =
[
    [ "core.h", "core_8h.html", null ],
    [ "pw_core_info", "structpw__core__info.html", [
      [ "id", "structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca", null ],
      [ "cookie", "structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083", null ],
      [ "user_name", "structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42", null ],
      [ "host_name", "structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f", null ],
      [ "version", "structpw__core__info.html#a3e394e50023a597dafb391887249d4eb", null ],
      [ "change_mask", "structpw__core__info.html#a25d93390dbafcb433827ec29c195404f", null ]
    ] ],
    [ "pw_core_events", "structpw__core__events.html", [
      [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ],
      [ "info", "structpw__core__events.html#aa6aae56a5a9eb60fd5a308bec837b0e6", null ],
      [ "done", "structpw__core__events.html#a6cf547297486e97c8969a1e08d837955", null ],
      [ "ping", "structpw__core__events.html#ada596905cb8c963eee644a638b6628c2", null ],
      [ "error", "structpw__core__events.html#a55c28400675736b9365e711884f7a73b", null ],
      [ "remove_id", "structpw__core__events.html#a9a930f32ad895727dffbeb6ae4c6e04d", null ],
      [ "bound_id", "structpw__core__events.html#ae99597f5f149475172942064d4911961", null ],
      [ "add_mem", "structpw__core__events.html#aeaf261e59f9a58b5005418abf669271a", null ],
      [ "remove_mem", "structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063", null ]
    ] ],
    [ "pw_core_methods", "structpw__core__methods.html", [
      [ "version", "structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a", null ],
      [ "add_listener", "structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703", null ],
      [ "hello", "structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5", null ],
      [ "sync", "structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176", null ],
      [ "pong", "structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9", null ],
      [ "error", "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa", null ],
      [ "get_registry", "structpw__core__methods.html#a570886edc43416b3dcd10b48016493af", null ],
      [ "create_object", "structpw__core__methods.html#a7e70c82277387a47a953d64b0ba82cce", null ],
      [ "destroy", "structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309", null ]
    ] ],
    [ "pw_core", "structpw__core.html", null ],
    [ "pw_registry", "structpw__registry.html", null ],
    [ "PW_TYPE_INTERFACE_Core", "group__pw__core.html#ga4828b5ffb309b2d8a985e0ee4fc80978", null ],
    [ "PW_TYPE_INTERFACE_Registry", "group__pw__core.html#gab77f9f893b6d0a0cc0827738479673e2", null ],
    [ "PW_VERSION_CORE", "group__pw__core.html#gaa1b9fbcde86380fd115be191535ccdf5", null ],
    [ "PW_VERSION_REGISTRY", "group__pw__core.html#gab44caf825808814cb78f9b6426457066", null ],
    [ "PW_DEFAULT_REMOTE", "group__pw__core.html#ga7a2591e137e97b0a693c0788031acab7", null ],
    [ "PW_ID_CORE", "group__pw__core.html#ga4083f3e9e51198a675c7fb0aa0f91769", null ],
    [ "PW_ID_ANY", "group__pw__core.html#ga5e904a63584ce9699c5c192bb4473cf9", null ],
    [ "PW_CORE_CHANGE_MASK_PROPS", "group__pw__core.html#ga787755cfb5d235fa3a961bcc7f65b3a8", null ],
    [ "PW_CORE_CHANGE_MASK_ALL", "group__pw__core.html#ga4c5b5cb41d6256b5262ca232f03ee6ef", null ],
    [ "PW_CORE_EVENT_INFO", "group__pw__core.html#ga20d8f8b7de5d61fd26279335081a650f", null ],
    [ "PW_CORE_EVENT_DONE", "group__pw__core.html#ga6320395eb7b0608d72876f528356d804", null ],
    [ "PW_CORE_EVENT_PING", "group__pw__core.html#gae5baf4bb04dc57c2f56c6ebe55495ee4", null ],
    [ "PW_CORE_EVENT_ERROR", "group__pw__core.html#ga26ec3a93936820d7766d161bd2061dde", null ],
    [ "PW_CORE_EVENT_REMOVE_ID", "group__pw__core.html#ga32442cfb83722413b8769555194f1837", null ],
    [ "PW_CORE_EVENT_BOUND_ID", "group__pw__core.html#ga7f5253f01173106d9f4204e6803f9eb7", null ],
    [ "PW_CORE_EVENT_ADD_MEM", "group__pw__core.html#gaa324107a2eb26e55ec2a6fab7c12cbc4", null ],
    [ "PW_CORE_EVENT_REMOVE_MEM", "group__pw__core.html#gaf42a0b2aece1dbb787791d92ccc9bf4c", null ],
    [ "PW_CORE_EVENT_NUM", "group__pw__core.html#gab5ff84f4e96706dcaf698a889d31ebb2", null ],
    [ "PW_VERSION_CORE_EVENTS", "group__pw__core.html#gaecb5def77dc04e427fda3af43fe56646", null ],
    [ "PW_CORE_METHOD_ADD_LISTENER", "group__pw__core.html#gab198dbd1143e47953104e4aa52106562", null ],
    [ "PW_CORE_METHOD_HELLO", "group__pw__core.html#ga91db1c249a8b6373869a6dc1461728b7", null ],
    [ "PW_CORE_METHOD_SYNC", "group__pw__core.html#ga7af83aeb249cf504499536e95793f650", null ],
    [ "PW_CORE_METHOD_PONG", "group__pw__core.html#ga4cf14818a2b4d7d2841e43d14706f24e", null ],
    [ "PW_CORE_METHOD_ERROR", "group__pw__core.html#gaad9f6725ef7bf5a40abc3993ee0eb661", null ],
    [ "PW_CORE_METHOD_GET_REGISTRY", "group__pw__core.html#ga61a14cc040ef8af2843ab3269292bee9", null ],
    [ "PW_CORE_METHOD_CREATE_OBJECT", "group__pw__core.html#ga3c4c5529b9bb6c9188053bdf1604c2e0", null ],
    [ "PW_CORE_METHOD_DESTROY", "group__pw__core.html#ga22add02684ab6cf7bcbb5971abf11b43", null ],
    [ "PW_CORE_METHOD_NUM", "group__pw__core.html#ga3377b3f78973fe86c320832c7c78ca11", null ],
    [ "PW_VERSION_CORE_METHODS", "group__pw__core.html#ga684305baa27764d91e1aef7faaf39afa", null ],
    [ "pw_core_method", "group__pw__core.html#gac59eea3db133de67f1b1c0ab4cab0047", null ],
    [ "pw_core_add_listener", "group__pw__core.html#gab938c1e0b4439c86f0c073d2359fefb0", null ],
    [ "pw_core_hello", "group__pw__core.html#gaeacb97f0a612cff9d5fdb16e2a205444", null ],
    [ "pw_core_sync", "group__pw__core.html#ga02b3e6ff573afd1efba25efc8bbb2538", null ],
    [ "pw_core_pong", "group__pw__core.html#ga50323f15b69d13b86fe1d59d6dd3bfba", null ],
    [ "pw_core_error", "group__pw__core.html#ga1c0700d8582be8c02db04c4f907b55c9", null ],
    [ "pw_core_destroy", "group__pw__core.html#ga747c2d5f60d3171f81ac5d58c34042a3", null ],
    [ "pw_core_info_update", "group__pw__core.html#gaf9ef57e634a1d3ba60e47a65608db03f", null ],
    [ "pw_core_info_merge", "group__pw__core.html#gae648ba2f9c03dabf37b4e1852a0c1924", null ],
    [ "pw_core_info_free", "group__pw__core.html#gacd6e564b199ca16be48656e77cb5003a", null ],
    [ "pw_core_errorv", "group__pw__core.html#ga06c0275ea988bc37118882895ec03433", null ],
    [ "pw_core_errorf", "group__pw__core.html#ga02ca8080671bb34a7f015eae9893bd9f", null ],
    [ "pw_core_get_registry", "group__pw__core.html#gac84664f761622bc7b98eabab717943af", null ],
    [ "pw_core_create_object", "group__pw__core.html#gaa0c5475dc6ef3a7d0c53383a5748ccc3", null ],
    [ "pw_context_connect", "group__pw__core.html#ga5994e3a54e4ec718094ca02a1234815b", null ],
    [ "pw_context_connect_fd", "group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02", null ],
    [ "pw_context_connect_self", "group__pw__core.html#ga6c4082146d47a5da6db219fbd4d8ab1d", null ],
    [ "pw_core_steal_fd", "group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f", null ],
    [ "pw_core_set_paused", "group__pw__core.html#gacd4995c9a07c46f925b28bf4c653f2df", null ],
    [ "pw_core_disconnect", "group__pw__core.html#gaa0ad30957ad355b5217f161cc7847c2f", null ],
    [ "pw_core_get_user_data", "group__pw__core.html#ga96e284c572b6ff30f66f796ccef6547b", null ],
    [ "pw_core_get_client", "group__pw__core.html#ga844067d3c4ee799eebb94db3d3c29e09", null ],
    [ "pw_core_get_context", "group__pw__core.html#ga00997c1dff9cc3e96934aea17ddcde94", null ],
    [ "pw_core_get_properties", "group__pw__core.html#ga6137f0b4ffe93b4051dc29baf262233d", null ],
    [ "pw_core_update_properties", "group__pw__core.html#ga9918e38cb727fa7b8d59cca7b318f3c7", null ],
    [ "pw_core_get_mempool", "group__pw__core.html#ga5b549ed4e92c3666c108591cb3ac3a55", null ],
    [ "pw_core_find_proxy", "group__pw__core.html#ga0f4adad3c19a2c184f6323f8d62443b1", null ],
    [ "pw_core_export", "group__pw__core.html#ga9f689fb870a35e081ceff7e689ad5e30", null ]
];
